@@ -55,7 +55,7 @@
 
 extern char *getenv();
 
-static String version = "Ghostview, version 1.4";
+static String version = "Ghostview, version 1.5";
 
 static XtResource resources[] = {
     {"showTitle", "Labels", XtRBoolean, sizeof(Boolean),
@@ -64,13 +64,6 @@ static XtResource resources[] = {
      XtOffsetOf(AppResources, show_date), XtRImmediate, (XtPointer)True},
     {"showLocator", "Labels", XtRBoolean, sizeof(Boolean),
      XtOffsetOf(AppResources, show_locator), XtRImmediate, (XtPointer)True},
-    {"installStdCmap", "InstallStdCmap", XtRBoolean, sizeof(Boolean),
-     XtOffsetOf(AppResources, install_std_cmap), XtRImmediate,
-     (XtPointer)False},
-    {"retainStdCmap", "RetainStdCmap", XtRBoolean, sizeof(Boolean),
-     XtOffsetOf(AppResources, retain_std_cmap), XtRImmediate, (XtPointer)True},
-    {"privateCmap", "PrivateCmap", XtRBoolean, sizeof(Boolean),
-     XtOffsetOf(AppResources, private_cmap), XtRImmediate, (XtPointer)False},
     {"autoCenter", "AutoCenter", XtRBoolean, sizeof(Boolean),
      XtOffsetOf(AppResources, auto_center), XtRImmediate, (XtPointer)True},
     {"horizontalMargin", "Margin", XtRInt, sizeof(int),
@@ -139,12 +132,9 @@ static XtResource resources[] = {
 };
 
 static XrmOptionDescRec options[] = {
-    {"-staticgray", "*Visual", XrmoptionNoArg, "StaticGray"},
-    {"-grayscale", "*Visual", XrmoptionNoArg, "GrayScale"},
-    {"-staticcolor", "*Visual", XrmoptionNoArg, "StaticColor"},
-    {"-pseudocolor", "*Visual", XrmoptionNoArg, "PseudoColor"},
-    {"-truecolor", "*Visual", XrmoptionNoArg, "TrueColor"},
-    {"-directcolor", "*Visual", XrmoptionNoArg, "DirectColor"},
+    {"-monochrome", "*Ghostview.palette", XrmoptionNoArg, "Monochrome"},
+    {"-grayscale", "*Ghostview.palette", XrmoptionNoArg, "Grayscale"},
+    {"-color", "*Ghostview.palette", XrmoptionNoArg, "Color"},
     {"-page", ".page", XrmoptionSepArg, NULL},
     {"-title", ".showTitle", XrmoptionNoArg, "True"},
     {"-notitle", ".showTitle", XrmoptionNoArg, "False"},
@@ -156,15 +146,11 @@ static XrmOptionDescRec options[] = {
     {"-nocenter", ".autoCenter", XrmoptionNoArg, "False"},
     {"-labels", ".Labels", XrmoptionNoArg, "True"},
     {"-nolabels", ".Labels", XrmoptionNoArg, "False"},
-    {"-install", ".installStdCmap", XrmoptionNoArg, "True"},
-    {"-noinstall", ".installStdCmap", XrmoptionNoArg, "False"},
-    {"-retain", ".retainStdCmap", XrmoptionNoArg, "True"},
-    {"-noretain", ".retainStdCmap", XrmoptionNoArg, "False"},
-    {"-private", ".privateCmap", XrmoptionNoArg, "True"},
-    {"-noprivate", ".privateCmap", XrmoptionNoArg, "False"},
     {"-quiet", "*Ghostview.quiet", XrmoptionNoArg, "True"},
     {"-noquiet", "*Ghostview.quiet", XrmoptionNoArg, "False"},
-    {"-preload", "*Ghostview.preload", XrmoptionSepArg, NULL},
+    {"-safer", "*Ghostview.safer", XrmoptionNoArg, "True"},
+    {"-nosafer", "*Ghostview.safer", XrmoptionNoArg, "False"},
+    {"-arguments", "*Ghostview.arguments", XrmoptionSepArg, NULL},
     {"-xdpi", "*Ghostview.xdpi", XrmoptionSepArg, NULL},
     {"-ydpi", "*Ghostview.ydpi", XrmoptionSepArg, NULL},
     {"-dpi", "*Ghostview.Resolution", XrmoptionSepArg, NULL},
@@ -297,10 +283,6 @@ int	mode;	/* tells what type of popup */
 time_t	mtime;		/* last modified time of input file */
 struct document *doc;	/* document structure */
 struct document *olddoc;	/* document structure */
-Colormap	cmap;	/* colormap being used */
-Boolean	special_cmap;	/* Is cmap not the Default Colormap */
-Pixel	white;		/* white pixel in above colormap */
-Pixel	black;		/* black pixel in above colormap */
 Atom	wm_delete_window;	/* Atom sent to destroy a window */
 XErrorHandler	old_Xerror;	/* standard error handler */
 Boolean	dying;		/* whether an X error caused our exit */
@@ -430,7 +412,6 @@ char *argv[];
     XtGetApplicationResources(toplevel, (XtPointer) &app_res,
 			      resources, XtNumber(resources), NULL, ZERO);
     if (s1 = getenv(app_res.printer_variable)) app_res.default_printer = s1;
-    SetStandardColormap(toplevel);
 
     /* Open Windows sometimes hands me a bad bitmap */
     if (app_res.openwindows) {
@@ -448,26 +429,13 @@ char *argv[];
     }
     
     /* Instantiate Popup children */
-							num_args = 0;
-    XtSetArg(args[num_args], XtNcolormap, cmap);	num_args++;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
     infopopup = XtCreatePopupShell("information", topLevelShellWidgetClass,
-				   toplevel, args, num_args);
+				   toplevel, NULL, ZERO);
 
-							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
     infoform = XtCreateManagedWidget("form", formWidgetClass,
-				     infopopup, args, num_args);
+				     infopopup, NULL, ZERO);
 
 							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
     XtSetArg(args[num_args], XtNtop, XtChainTop);	num_args++;
     XtSetArg(args[num_args], XtNbottom, XtChainBottom);	num_args++;
     XtSetArg(args[num_args], XtNleft, XtChainLeft);	num_args++;
@@ -481,10 +449,6 @@ char *argv[];
 				     infoform, args, num_args);
 
 							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
     XtSetArg(args[num_args], XtNfromVert, infotext);	num_args++;
     XtSetArg(args[num_args], XtNtop, XtChainBottom);	num_args++;
     XtSetArg(args[num_args], XtNbottom, XtChainBottom);	num_args++;
@@ -512,26 +476,13 @@ char *argv[];
     XtRealizeWidget(infopopup);
     XSetWMProtocols(dpy, XtWindow(infopopup), &wm_delete_window, 1);
 
-							num_args = 0;
-    XtSetArg(args[num_args], XtNcolormap, cmap);	num_args++;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
     copyrightpopup = XtCreatePopupShell("copyright", topLevelShellWidgetClass,
-					toplevel, args, num_args);
+					toplevel, NULL, ZERO);
 
-							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
     copyrightform = XtCreateManagedWidget("form", formWidgetClass,
-					  copyrightpopup, args, num_args);
+					  copyrightpopup, NULL, ZERO);
 
 							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
     XtSetArg(args[num_args], XtNtop, XtChainTop);	num_args++;
     XtSetArg(args[num_args], XtNbottom, XtChainBottom);	num_args++;
     XtSetArg(args[num_args], XtNleft, XtChainLeft);	num_args++;
@@ -548,10 +499,6 @@ char *argv[];
 					  copyrightform, args, num_args);
 
 							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
     XtSetArg(args[num_args], XtNfromVert, copyrighttext);
 							num_args++;
     XtSetArg(args[num_args], XtNtop, XtChainBottom);	num_args++;
@@ -581,13 +528,8 @@ char *argv[];
     XtRealizeWidget(copyrightpopup);
     XSetWMProtocols(dpy, XtWindow(copyrightpopup), &wm_delete_window, 1);
 
-							num_args = 0;
-    XtSetArg(args[num_args], XtNcolormap, cmap);	num_args++;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
     dialogpopup = XtCreatePopupShell("popup", transientShellWidgetClass,
-				     toplevel, args, num_args);
+				     toplevel, NULL, ZERO);
 
     dialog = CreateDialog(dialogpopup, "dialog", okay, dismiss);
     XtRealizeWidget(dialogpopup);
@@ -596,22 +538,14 @@ char *argv[];
 
     /* Instantiate Widgets */
 
-							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
     form = XtCreateManagedWidget("form", formWidgetClass,
-				 toplevel, args, num_args);
+				 toplevel, NULL, ZERO);
 
     above_toc = NULL;
     left_of_page = NULL;
     set_vert_dist = False;
     if (app_res.show_title) {
 							num_args = 0;
-	if (special_cmap) {
-	    XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	    XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-	}
 	XtSetArg(args[num_args], XtNfromVert, above_toc);num_args++;
 	XtSetArg(args[num_args], XtNtop, XtChainTop);	num_args++;
 	XtSetArg(args[num_args], XtNbottom, XtChainTop);num_args++;
@@ -631,10 +565,6 @@ char *argv[];
 
     if (app_res.show_date) {
 							num_args = 0;
-	if (special_cmap) {
-	    XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	    XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-	}
 	XtSetArg(args[num_args], XtNfromVert, above_toc);num_args++;
 	if (set_vert_dist) {
 	    XtSetArg(args[num_args], XtNvertDistance, 0);num_args++;
@@ -656,10 +586,6 @@ char *argv[];
 
     if (app_res.show_locator) {
 							num_args = 0;
-	if (special_cmap) {
-	    XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	    XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-	}
 	XtSetArg(args[num_args], XtNfromVert, above_toc);num_args++;
 	if (set_vert_dist) {
 	    XtSetArg(args[num_args], XtNvertDistance, 0);num_args++;
@@ -679,9 +605,6 @@ char *argv[];
     }
 
 							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
     XtSetArg(args[num_args], XtNfromVert, above_toc);	num_args++;
     XtSetArg(args[num_args], XtNtop, XtChainTop);	num_args++;
     XtSetArg(args[num_args], XtNbottom, XtChainTop);	num_args++;
@@ -691,299 +614,140 @@ char *argv[];
     XtSetArg(args[num_args], XtNallowVert, True);	num_args++;
     box = XtCreateManagedWidget("box", boxWidgetClass, form, args, num_args);
 
-							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
-    XtSetArg(args[num_args], XtNresize, False);	num_args++;
+    XtSetArg(args[0], XtNresize, False);
     filebutton = XtCreateManagedWidget("fileButton", menuButtonWidgetClass,
-				       box, args, num_args);
+				       box, args, ONE);
 
-							num_args = 0;
-    XtSetArg(args[num_args], XtNcolormap, cmap);	num_args++;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
     filemenu = XtCreatePopupShell("menu", simpleMenuWidgetClass,
-				  filebutton, args, num_args);
+				  filebutton, NULL, ZERO);
 
-							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
     openbutton = XtCreateManagedWidget("open", smeBSBObjectClass,
-				       filemenu, args, num_args);
+				       filemenu, NULL, ZERO);
     XtAddCallback(openbutton, XtNcallback, popup_dialog, (XtPointer)OPEN);
 
-							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
     reopenbutton = XtCreateManagedWidget("reopen", smeBSBObjectClass,
-				         filemenu, args, num_args);
+				         filemenu, NULL, ZERO);
     XtAddCallback(reopenbutton, XtNcallback, reopen_file, (XtPointer)NULL);
 
-							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
     printwholebutton = XtCreateManagedWidget("printwhole", smeBSBObjectClass,
-				             filemenu, args, num_args);
+				             filemenu, NULL, ZERO);
     XtAddCallback(printwholebutton, XtNcallback, popup_dialog,
 		  (XtPointer)PRINT_WHOLE);
 
-							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
     printmarkedbutton = XtCreateManagedWidget("printmarked", smeBSBObjectClass,
-				              filemenu, args, num_args);
+				              filemenu, NULL, ZERO);
     XtAddCallback(printmarkedbutton, XtNcallback, popup_dialog,
 		  (XtPointer)PRINT_MARKED);
 
-							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
     savebutton = XtCreateManagedWidget("save", smeBSBObjectClass,
-				       filemenu, args, num_args);
+				       filemenu, NULL, ZERO);
     XtAddCallback(savebutton, XtNcallback, popup_dialog, (XtPointer)SAVE);
 
-							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
     line = XtCreateManagedWidget("line", smeLineObjectClass,
-				 filemenu, args, num_args);
+				 filemenu, NULL, ZERO);
 
-							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
     copyrightbutton = XtCreateManagedWidget("copyright", smeBSBObjectClass,
-					    filemenu, args, num_args);
+					    filemenu, NULL, ZERO);
     XtAddCallback(copyrightbutton, XtNcallback, popup,
 		  (XtPointer)copyrightpopup);
 
-							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
     quitbutton = XtCreateManagedWidget("quit", smeBSBObjectClass,
-				       filemenu, args, num_args);
+				       filemenu, NULL, ZERO);
     XtAddCallback(quitbutton, XtNcallback, quit_ghostview, (XtPointer)0);
 
-							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
-    XtSetArg(args[num_args], XtNresize, False);	num_args++;
+    XtSetArg(args[0], XtNresize, False);
     pagebutton = XtCreateManagedWidget("pageButton", menuButtonWidgetClass,
-				       box, args, num_args);
+				       box, args, 1);
 
-							num_args = 0;
-    XtSetArg(args[num_args], XtNcolormap, cmap);	num_args++;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
     pagemenu = XtCreatePopupShell("menu", simpleMenuWidgetClass,
-				  pagebutton, args, num_args);
+				  pagebutton, NULL, ZERO);
 
-							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
     nextbutton = XtCreateManagedWidget("next", smeBSBObjectClass,
-				       pagemenu, args, num_args);
+				       pagemenu, NULL, ZERO);
     XtAddCallback(nextbutton, XtNcallback, next_page, (XtPointer)0);
 
-							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
     showbutton = XtCreateManagedWidget("show", smeBSBObjectClass,
-				       pagemenu, args, num_args);
+				       pagemenu, NULL, ZERO);
     XtAddCallback(showbutton, XtNcallback, this_page, (XtPointer)0);
 
-							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
     prevbutton = XtCreateManagedWidget("prev", smeBSBObjectClass,
-				       pagemenu, args, num_args);
+				       pagemenu, NULL, ZERO);
     XtAddCallback(prevbutton, XtNcallback, prev_page, (XtPointer)0);
 
-							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
     line = XtCreateManagedWidget("line", smeLineObjectClass,
-				 pagemenu, args, num_args);
+				 pagemenu, NULL, ZERO);
 
-							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
     centerbutton = XtCreateManagedWidget("center", smeBSBObjectClass,
-				       pagemenu, args, num_args);
+				       pagemenu, NULL, ZERO);
     XtAddCallback(centerbutton, XtNcallback, center_page, (XtPointer)0);
 
-							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
     line = XtCreateManagedWidget("line", smeLineObjectClass,
-				 pagemenu, args, num_args);
+				 pagemenu, NULL, ZERO);
 
-							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
     markbutton = XtCreateManagedWidget("mark", smeBSBObjectClass,
-				       pagemenu, args, num_args);
+				       pagemenu, NULL, ZERO);
     XtAddCallback(markbutton, XtNcallback, mark_page, (XtPointer)0);
 
-							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
     unmarkbutton = XtCreateManagedWidget("unmark", smeBSBObjectClass,
-				         pagemenu, args, num_args);
+				         pagemenu, NULL, ZERO);
     XtAddCallback(unmarkbutton, XtNcallback, unmark_page, (XtPointer)0);
 
-							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
-    XtSetArg(args[num_args], XtNresize, False);	num_args++;
+    XtSetArg(args[0], XtNresize, False);
     magstepbutton = XtCreateManagedWidget("magstepButton",
 					  menuButtonWidgetClass,
-					  box, args, num_args);
+					  box, args, ONE);
 
-							num_args = 0;
-    XtSetArg(args[num_args], XtNcolormap, cmap);	num_args++;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
     magstepmenu = XtCreatePopupShell("menu", simpleMenuWidgetClass,
-				     magstepbutton, args, num_args);
+				     magstepbutton, NULL, ZERO);
 
     magstepentry = (Widget *) XtMalloc(
 	    (app_res.maximum_magstep - app_res.minimum_magstep + 1) *
 	    sizeof(Widget));
+    XtSetArg(args[0], XtNleftMargin, 20);
     for (i = app_res.minimum_magstep; i <= app_res.maximum_magstep; i++) {
 	char buf[16];
 	sprintf(buf, "%d", i);
-							num_args = 0;
-	if (special_cmap) {
-	    XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	    XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-	}
-	XtSetArg(args[num_args], XtNleftMargin, 20);	num_args++;
 	magstepentry[i-app_res.minimum_magstep] =
 		XtCreateManagedWidget(buf, smeBSBObjectClass,
-				      magstepmenu, args, num_args);
+				      magstepmenu, args, 1);
 	XtAddCallback(magstepentry[i-app_res.minimum_magstep], XtNcallback,
 		      set_magstep, (XtPointer)i);
     }
 
-							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
-    XtSetArg(args[num_args], XtNresize, False);	num_args++;
+    XtSetArg(args[0], XtNresize, False);
     orientationbutton = XtCreateManagedWidget("orientationButton",
 					      menuButtonWidgetClass,
-					      box, args, num_args);
+					      box, args, ONE);
 
-							num_args = 0;
-    XtSetArg(args[num_args], XtNcolormap, cmap);	num_args++;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
     orientationmenu = XtCreatePopupShell("menu", simpleMenuWidgetClass,
-				         orientationbutton, args, num_args);
+				         orientationbutton, NULL, ZERO);
 
-							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
-    XtSetArg(args[num_args], XtNleftMargin, 20);	num_args++;
+    XtSetArg(args[0], XtNleftMargin, 20);
     portraitbutton = XtCreateManagedWidget("portrait", smeBSBObjectClass,
-				           orientationmenu, args, num_args);
+				           orientationmenu, args, ONE);
     XtAddCallback(portraitbutton, XtNcallback,
 		  set_orientation, (XtPointer)XtPageOrientationPortrait);
 
-							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
-    XtSetArg(args[num_args], XtNleftMargin, 20);	num_args++;
     landscapebutton = XtCreateManagedWidget("landscape", smeBSBObjectClass,
-				            orientationmenu, args, num_args);
+				            orientationmenu, args, ONE);
     XtAddCallback(landscapebutton, XtNcallback,
 		  set_orientation, (XtPointer)XtPageOrientationLandscape);
 
-							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
-    XtSetArg(args[num_args], XtNleftMargin, 20);	num_args++;
     upsidedownbutton = XtCreateManagedWidget("upsidedown", smeBSBObjectClass,
-				             orientationmenu, args, num_args);
+				             orientationmenu, args, ONE);
     XtAddCallback(upsidedownbutton, XtNcallback,
 		  set_orientation, (XtPointer)XtPageOrientationUpsideDown);
 
-							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
-    XtSetArg(args[num_args], XtNleftMargin, 20);	num_args++;
     seascapebutton = XtCreateManagedWidget("seascape", smeBSBObjectClass,
-				             orientationmenu, args, num_args);
+				             orientationmenu, args, ONE);
     XtAddCallback(seascapebutton, XtNcallback,
 		  set_orientation, (XtPointer)XtPageOrientationSeascape);
 
-							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
     line = XtCreateManagedWidget("line", smeLineObjectClass,
-				 orientationmenu, args, num_args);
+				 orientationmenu, NULL, ZERO);
 
-							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
-    XtSetArg(args[num_args], XtNleftMargin, 20);	num_args++;
     swapbutton = XtCreateManagedWidget("swap", smeBSBObjectClass,
-				       orientationmenu, args, num_args);
+				       orientationmenu, args, ONE);
     XtAddCallback(swapbutton, XtNcallback, swap_landscape, (XtPointer)0);
 
     if (app_res.swap_landscape) {
@@ -1001,15 +765,10 @@ char *argv[];
 	XtFree(s2);
     }
 
-							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
-    XtSetArg(args[num_args], XtNresize, False);	num_args++;
+    XtSetArg(args[0], XtNresize, False);
     pagemediabutton = XtCreateManagedWidget("pagemediaButton",
 					    menuButtonWidgetClass,
-					    box, args, num_args);
+					    box, args, ONE);
 
     default_pagemedia = 0;
     for (i = 0; papersizes[i].name; i++) {
@@ -1044,10 +803,6 @@ char *argv[];
     XtSetValues(pagemediabutton, args, ONE);
 
 							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNforeground, black);	num_args++;
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
     XtSetArg(args[num_args], XtNfromVert, above_toc);	num_args++;
     XtSetArg(args[num_args], XtNfromHoriz, box);	num_args++;
     XtSetArg(args[num_args], XtNtop, XtChainTop);	num_args++;
@@ -1066,9 +821,6 @@ char *argv[];
     if (!left_of_page) left_of_page = toc;
 
 							num_args = 0;
-    if (special_cmap) {
-	XtSetArg(args[num_args], XtNbackground, white);	num_args++;
-    }
     XtSetArg(args[num_args], XtNfromHoriz, left_of_page);num_args++;
     XtSetArg(args[num_args], XtNtop, XtChainTop);	num_args++;
     XtSetArg(args[num_args], XtNbottom, XtChainBottom);	num_args++;
@@ -1080,10 +832,8 @@ char *argv[];
     pageview = XtCreateManagedWidget("pageview", viewportWidgetClass,
 				     form, args, num_args);
 
-							num_args = 0;
-    XtSetArg(args[num_args], XtNbackground, white);	num_args++;
     page = XtCreateManagedWidget("page", ghostviewWidgetClass,
-				 pageview, args, num_args);
+				 pageview, NULL, ZERO);
     num_ghosts++;
     XtAddCallback(page, XtNcallback, track_and_zoom, (XtPointer)0);
     XtAddCallback(page, XtNdestroyCallback, destroy_ghost, (XtPointer)page);
@@ -1143,21 +893,19 @@ char *call;
     XtDestroyApplicationContext(app_con);
     fprintf(stderr, "Usage: %s\n", call);
     fprintf(stderr,
-		"    [-staticgray] [-grayscale] [-staticcolor]\n");
-    fprintf(stderr,
-		"    [-pseudocolor] [-truecolor] [-directcolor]\n");
-    fprintf(stderr,
-		"    [-[no]install] [-[no]private] [-[no]center]\n");
+		"    [-monochrome] [-grayscale] [-color]\n");
     fprintf(stderr,
 		"    [-[no]title] [-[no]date] [-[no]locator] [-[no]labels]\n");
     fprintf(stderr,
 		"    [-resolution <dpi>] [-dpi <dpi>]\n");
     fprintf(stderr,
-		"    [-xdpi <dpi>] [-ydpi <dpi>]\n");
+		"    [-xdpi <dpi>] [-ydpi <dpi>] [-magstep <n>]\n");
     fprintf(stderr,
-		"    [-[no]quiet] [-preload <file>] [-magstep <n>]\n");
+		"    [-[no]safer] [-[no]quiet] [-arguments <arguments>]\n");
     fprintf(stderr,
-		"    [-portrait] [-landscape] [-upsidedown] [-seascape]\n");
+		"    [-[no]center]\n");
+    fprintf(stderr,
+		"    [-portrait] [-landscape] [-upsidedown] [-seascape] [-[no]swap]\n");
     fprintf(stderr,
 		"    [-letter] [-tabloid] [-ledger] [-legal] [-statement]\n");
     fprintf(stderr,
@@ -1167,7 +915,7 @@ char *call;
     fprintf(stderr,
 		"    [-force] [-forceorientation] [-forcemedia]\n");
     fprintf(stderr,
-		"    [-[no]swap] [-[no]openwindows] [-[no]ncdwm]\n");
+		"    [-[no]openwindows] [-[no]ncdwm]\n");
     fprintf(stderr,
 		"    [-page <label>] [toolkitoption]\n");
     fprintf(stderr,
